bayespy.inference.vmp.nodes.binomial.BinomialDistribution.__init__
==================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. automethod:: BinomialDistribution.__init__